/*********************************************************************
*                SEGGER MICROCONTROLLER GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 2003-2014     SEGGER Microcontroller GmbH & Co KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : GUI_OS_Status.c
Purpose : emWin and embOS demo application showing system and task
          specific values.
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"
#include "GUI.h"
#include "HEADER.h"
#include "FRAMEWIN.h"
#include "LISTVIEW.h"
#include <string.h>
#include <stdio.h>


/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#ifndef GUI_CONST_STORAGE
  #define GUI_CONST_STORAGE const
#endif


static GUI_CONST_STORAGE unsigned char acSeggerLogo120[] = {
  /* ABS: 004 Pixels @ 000,000*/ 0, 4, 0xFF, 0xFF, 0x7D, 0xEF, 0x8E, 0x73, 0x82, 0x10,
  /* RLE: 112 Pixels @ 004,000*/ 112, 0x00, 0x00,
  /* ABS: 006 Pixels @ 116,000*/ 0, 6, 0x82, 0x10, 0x8E, 0x73, 0x7D, 0xEF, 0xFF, 0xFF, 0x7D, 0xEF, 0x86, 0x31,
  /* RLE: 116 Pixels @ 002,001*/ 116, 0x00, 0x00,
  /* ABS: 007 Pixels @ 118,001*/ 0, 7, 0x86, 0x31, 0x7D, 0xEF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x8A, 0x52,
  /* RLE: 110 Pixels @ 005,002*/ 110, 0x10, 0x84,
  /* ABS: 009 Pixels @ 115,002*/ 0, 9, 0x8A, 0x52, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE,
  /* RLE: 112 Pixels @ 004,003*/ 112, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 116,003*/ 0, 7, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x08, 0x42,
  /* RLE: 114 Pixels @ 003,004*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,004*/ 1, 0x08, 0x42,
  /* RLE: 004 Pixels @ 118,004*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,005*/ 1, 0x10, 0x84,
  /* RLE: 114 Pixels @ 003,005*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,005*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,005*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,006*/ 1, 0x10, 0x84,
  /* RLE: 114 Pixels @ 003,006*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,006*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,006*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,007*/ 1, 0x10, 0x84,
  /* RLE: 114 Pixels @ 003,007*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,007*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,007*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,008*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x38, 0xE6, 0xE7, 0xA9, 0x65, 0xA1, 0x38, 0xE6,
  /* RLE: 007 Pixels @ 010,008*/ 7, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 017,008*/ 0, 4, 0xF3, 0xD4, 0x65, 0xA1, 0xCB, 0xBA, 0x1C, 0xF7,
  /* RLE: 096 Pixels @ 021,008*/ 96, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,008*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,008*/ 4, 0x00, 0x00,
  /* ABS: 009 Pixels @ 002,009*/ 0, 9, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x1C, 0xF7,
  /* RLE: 005 Pixels @ 011,009*/ 5, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 016,009*/ 0, 5, 0x1C, 0xF7, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 096 Pixels @ 021,009*/ 96, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,009*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,009*/ 4, 0x00, 0x00,
  /* ABS: 009 Pixels @ 002,010*/ 0, 9, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x49, 0xB2, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 005 Pixels @ 011,010*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 016,010*/ 1, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 017,010*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 021,010*/ 1, 0xAE, 0xC3,
  /* RLE: 095 Pixels @ 022,010*/ 95, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,010*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,010*/ 4, 0x00, 0x00,
  /* ABS: 005 Pixels @ 002,011*/ 0, 5, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x38, 0xE6,
  /* RLE: 004 Pixels @ 007,011*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 011,011*/ 1, 0x10, 0xCC,
  /* RLE: 005 Pixels @ 012,011*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 017,011*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 018,011*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 022,011*/ 1, 0x55, 0xDD,
  /* RLE: 094 Pixels @ 023,011*/ 94, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,011*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,011*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,012*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 003,012*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 007,012*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 008,012*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 012,012*/ 1, 0xD7, 0xE5,
  /* RLE: 005 Pixels @ 013,012*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 018,012*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 093 Pixels @ 024,012*/ 93, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,012*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,012*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,013*/ 1, 0x10, 0x84,
  /* RLE: 005 Pixels @ 003,013*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 008,013*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x1C, 0xF7,
  /* RLE: 004 Pixels @ 014,013*/ 4, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 018,013*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 092 Pixels @ 025,013*/ 92, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,013*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,013*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,014*/ 1, 0x10, 0x84,
  /* RLE: 005 Pixels @ 003,014*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 008,014*/ 0, 6, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 005 Pixels @ 014,014*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 019,014*/ 0, 6, 0xBA, 0xEE, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x2C, 0xBB,
  /* RLE: 092 Pixels @ 025,014*/ 92, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,014*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,014*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,015*/ 1, 0x10, 0x84,
  /* RLE: 006 Pixels @ 003,015*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 009,015*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 010,015*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 014,015*/ 1, 0x10, 0xCC,
  /* RLE: 005 Pixels @ 015,015*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 020,015*/ 1, 0x55, 0xDD,
  /* RLE: 004 Pixels @ 021,015*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 025,015*/ 1, 0x92, 0xD4,
  /* RLE: 091 Pixels @ 026,015*/ 91, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,015*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,015*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,016*/ 1, 0x10, 0x84,
  /* RLE: 007 Pixels @ 003,016*/ 7, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 010,016*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 011,016*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 015,016*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 016,016*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 021,016*/ 1, 0xAE, 0xC3,
  /* RLE: 004 Pixels @ 022,016*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 026,016*/ 1, 0x38, 0xE6,
  /* RLE: 090 Pixels @ 027,016*/ 90, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,016*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,016*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,017*/ 1, 0x10, 0x84,
  /* RLE: 008 Pixels @ 003,017*/ 8, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 011,017*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 017,017*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 022,017*/ 0, 6, 0x49, 0xB2, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x9E, 0xFF,
  /* RLE: 089 Pixels @ 028,017*/ 89, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,017*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,017*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,018*/ 1, 0x10, 0x84,
  /* RLE: 008 Pixels @ 003,018*/ 8, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 011,018*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 018,018*/ 4, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 022,018*/ 0, 6, 0x1C, 0xF7, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 089 Pixels @ 028,018*/ 89, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,018*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,018*/ 4, 0x00, 0x00,
  /* ABS: 005 Pixels @ 002,019*/ 0, 5, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x1C, 0xF7,
  /* RLE: 005 Pixels @ 007,019*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 012,019*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 013,019*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 017,019*/ 1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 018,019*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 023,019*/ 1, 0x38, 0xE6,
  /* RLE: 004 Pixels @ 024,019*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 028,019*/ 1, 0x10, 0xCC,
  /* RLE: 088 Pixels @ 029,019*/ 88, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,019*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,019*/ 4, 0x00, 0x00,
  /* ABS: 006 Pixels @ 002,020*/ 0, 6, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 008,020*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 013,020*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 014,020*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 018,020*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 019,020*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 024,020*/ 1, 0x92, 0xD4,
  /* RLE: 004 Pixels @ 025,020*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 029,020*/ 1, 0x55, 0xDD,
  /* RLE: 087 Pixels @ 030,020*/ 87, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,020*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,020*/ 4, 0x00, 0x00,
  /* ABS: 006 Pixels @ 002,021*/ 0, 6, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x2C, 0xBB,
  /* RLE: 006 Pixels @ 008,021*/ 6, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 014,021*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 020,021*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 025,021*/ 0, 6, 0xCB, 0xBA, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 086 Pixels @ 031,021*/ 86, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,021*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,021*/ 4, 0x00, 0x00,
  /* ABS: 007 Pixels @ 002,022*/ 0, 7, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0xF3, 0xD4,
  /* RLE: 005 Pixels @ 009,022*/ 5, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 014,022*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 021,022*/ 4, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 025,022*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 085 Pixels @ 032,022*/ 85, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,022*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,022*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,023*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 010,023*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 015,023*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 016,023*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 020,023*/ 1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 021,023*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 026,023*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 027,023*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 031,023*/ 1, 0xAE, 0xC3,
  /* RLE: 085 Pixels @ 032,023*/ 85, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,023*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,023*/ 4, 0x00, 0x00,
  /* ABS: 009 Pixels @ 002,024*/ 0, 9, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 011,024*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 016,024*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 017,024*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 021,024*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 022,024*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 027,024*/ 1, 0x55, 0xDD,
  /* RLE: 004 Pixels @ 028,024*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 032,024*/ 1, 0x49, 0xB2,
  /* RLE: 079 Pixels @ 033,024*/ 79, 0xCB, 0xBA,
  /* RLE: 001 Pixels @ 112,024*/ 1, 0xD7, 0xE5,
  /* RLE: 004 Pixels @ 113,024*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,024*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,024*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,025*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 004 Pixels @ 006,025*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 010,025*/ 1, 0x2C, 0xBB,
  /* RLE: 006 Pixels @ 011,025*/ 6, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 017,025*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 023,025*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 028,025*/ 1, 0xAE, 0xC3,
  /* RLE: 084 Pixels @ 029,025*/ 84, 0x04, 0xA1,
  /* RLE: 004 Pixels @ 113,025*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,025*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,025*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,026*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 005 Pixels @ 006,026*/ 5, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 011,026*/ 1, 0xF3, 0xD4,
  /* RLE: 005 Pixels @ 012,026*/ 5, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 017,026*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 024,026*/ 4, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 028,026*/ 0, 2, 0x9E, 0xFF, 0x49, 0xB2,
  /* RLE: 083 Pixels @ 030,026*/ 83, 0x04, 0xA1,
  /* ABS: 005 Pixels @ 113,026*/ 0, 5, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,026*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,027*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 006 Pixels @ 006,027*/ 6, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 012,027*/ 1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 013,027*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 018,027*/ 0, 6, 0xBA, 0xEE, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 024,027*/ 5, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 029,027*/ 0, 2, 0xBA, 0xEE, 0xE7, 0xA9,
  /* RLE: 081 Pixels @ 031,027*/ 81, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 112,027*/ 1, 0x10, 0xCC,
  /* RLE: 004 Pixels @ 113,027*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,027*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,027*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,028*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 006 Pixels @ 006,028*/ 6, 0x04, 0xA1,
  /* ABS: 002 Pixels @ 012,028*/ 0, 2, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 014,028*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 019,028*/ 1, 0x55, 0xDD,
  /* RLE: 004 Pixels @ 020,028*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 024,028*/ 1, 0x55, 0xDD,
  /* RLE: 092 Pixels @ 025,028*/ 92, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,028*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,028*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,029*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 007 Pixels @ 006,029*/ 7, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 013,029*/ 1, 0xAE, 0xC3,
  /* RLE: 006 Pixels @ 014,029*/ 6, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 020,029*/ 0, 5, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xE7, 0xA9,
  /* RLE: 092 Pixels @ 025,029*/ 92, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,029*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,029*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,030*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 007 Pixels @ 006,030*/ 7, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 013,030*/ 1, 0xF3, 0xD4,
  /* RLE: 005 Pixels @ 014,030*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 019,030*/ 0, 6, 0x9E, 0xFF, 0x49, 0xB2, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xCB, 0xBA,
  /* RLE: 092 Pixels @ 025,030*/ 92, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,030*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,030*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,031*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 006 Pixels @ 006,031*/ 6, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 012,031*/ 1, 0x2C, 0xBB,
  /* RLE: 006 Pixels @ 013,031*/ 6, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 019,031*/ 0, 6, 0xAE, 0xC3, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 025,031*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 030,031*/ 1, 0xBA, 0xEE,
  /* RLE: 081 Pixels @ 031,031*/ 81, 0x38, 0xE6,
  /* RLE: 001 Pixels @ 112,031*/ 1, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 113,031*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,031*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,031*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,032*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 005 Pixels @ 006,032*/ 5, 0x04, 0xA1,
  /* ABS: 002 Pixels @ 011,032*/ 0, 2, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 013,032*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 018,032*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 019,032*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 023,032*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 024,032*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 029,032*/ 1, 0x55, 0xDD,
  /* RLE: 082 Pixels @ 030,032*/ 82, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 112,032*/ 1, 0x49, 0xB2,
  /* RLE: 004 Pixels @ 113,032*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,032*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,032*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,033*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 005 Pixels @ 006,033*/ 5, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 011,033*/ 1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 012,033*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 017,033*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 018,033*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 022,033*/ 1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 023,033*/ 5, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 028,033*/ 0, 2, 0xBA, 0xEE, 0x65, 0xA1,
  /* RLE: 083 Pixels @ 030,033*/ 83, 0x04, 0xA1,
  /* ABS: 005 Pixels @ 113,033*/ 0, 5, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,033*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 002,034*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 004 Pixels @ 006,034*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 010,034*/ 1, 0xF3, 0xD4,
  /* RLE: 005 Pixels @ 011,034*/ 5, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 016,034*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 023,034*/ 4, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 027,034*/ 0, 2, 0x9E, 0xFF, 0x49, 0xB2,
  /* RLE: 083 Pixels @ 029,034*/ 83, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 112,034*/ 1, 0xE7, 0xA9,
  /* RLE: 004 Pixels @ 113,034*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,034*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,034*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,035*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x2C, 0xBB,
  /* RLE: 006 Pixels @ 010,035*/ 6, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 016,035*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 022,035*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 027,035*/ 1, 0x2C, 0xBB,
  /* RLE: 004 Pixels @ 028,035*/ 4, 0x04, 0xA1,
  /* RLE: 079 Pixels @ 032,035*/ 79, 0x92, 0xD4,
  /* ABS: 002 Pixels @ 111,035*/ 0, 2, 0xF3, 0xD4, 0x1C, 0xF7,
  /* RLE: 004 Pixels @ 113,035*/ 4, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,035*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,035*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,036*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0xE7, 0xA9, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 010,036*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 015,036*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 016,036*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 020,036*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 021,036*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 026,036*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 027,036*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 031,036*/ 1, 0x55, 0xDD,
  /* RLE: 085 Pixels @ 032,036*/ 85, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,036*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,036*/ 4, 0x00, 0x00,
  /* ABS: 007 Pixels @ 002,037*/ 0, 7, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0x04, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 009,037*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 014,037*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 015,037*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 019,037*/ 1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 020,037*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 025,037*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 026,037*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 030,037*/ 1, 0xAE, 0xC3,
  /* RLE: 086 Pixels @ 031,037*/ 86, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,037*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,037*/ 4, 0x00, 0x00,
  /* ABS: 006 Pixels @ 002,038*/ 0, 6, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0xA1, 0xF3, 0xD4,
  /* RLE: 005 Pixels @ 008,038*/ 5, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 013,038*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 020,038*/ 4, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 024,038*/ 0, 7, 0x9E, 0xFF, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 086 Pixels @ 031,038*/ 86, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,038*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,038*/ 4, 0x00, 0x00,
  /* ABS: 005 Pixels @ 002,039*/ 0, 5, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x2C, 0xBB,
  /* RLE: 006 Pixels @ 007,039*/ 6, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 013,039*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 005 Pixels @ 019,039*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 024,039*/ 0, 6, 0xCB, 0xBA, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x1C, 0xF7,
  /* RLE: 005 Pixels @ 030,039*/ 5, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 035,039*/ 0, 5, 0x79, 0xCE, 0xF7, 0xBD, 0xF7, 0xBD, 0xF7, 0xBD, 0x79, 0xCE,
  /* RLE: 021 Pixels @ 040,039*/ 21, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 061,039*/ 1, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 062,039*/ 4, 0xF7, 0xBD,
  /* RLE: 010 Pixels @ 066,039*/ 10, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 076,039*/ 1, 0xFB, 0xDE,
  /* RLE: 004 Pixels @ 077,039*/ 4, 0xF7, 0xBD,
  /* RLE: 036 Pixels @ 081,039*/ 36, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,039*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,039*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,040*/ 1, 0x10, 0x84,
  /* RLE: 009 Pixels @ 003,040*/ 9, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 012,040*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 013,040*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 017,040*/ 1, 0x55, 0xDD,
  /* RLE: 005 Pixels @ 018,040*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 023,040*/ 1, 0x10, 0xCC,
  /* RLE: 004 Pixels @ 024,040*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 028,040*/ 1, 0xD7, 0xE5,
  /* RLE: 004 Pixels @ 029,040*/ 4, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 033,040*/ 0, 2, 0x71, 0x8C, 0x82, 0x10,
  /* RLE: 005 Pixels @ 035,040*/ 5, 0x00, 0x00,
  /* ABS: 006 Pixels @ 040,040*/ 0, 6, 0x04, 0x21, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD,
  /* RLE: 009 Pixels @ 046,040*/ 9, 0x00, 0x00,
  /* ABS: 006 Pixels @ 055,040*/ 0, 6, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0x8A, 0x52,
  /* RLE: 006 Pixels @ 061,040*/ 6, 0x00, 0x00,
  /* ABS: 002 Pixels @ 067,040*/ 0, 2, 0x0C, 0x63, 0xFB, 0xDE,
  /* RLE: 005 Pixels @ 069,040*/ 5, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 074,040*/ 0, 2, 0xF7, 0xBD, 0x08, 0x42,
  /* RLE: 005 Pixels @ 076,040*/ 5, 0x00, 0x00,
  /* ABS: 008 Pixels @ 081,040*/ 0, 8, 0x82, 0x10, 0x0C, 0x63, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0x82, 0x10,
  /* RLE: 008 Pixels @ 089,040*/ 8, 0x00, 0x00,
  /* ABS: 004 Pixels @ 097,040*/ 0, 4, 0x86, 0x31, 0xFF, 0xFF, 0xFF, 0xFF, 0x0C, 0x63,
  /* RLE: 007 Pixels @ 101,040*/ 7, 0x00, 0x00,
  /* ABS: 003 Pixels @ 108,040*/ 0, 3, 0x82, 0x10, 0x0C, 0x63, 0xFB, 0xDE,
  /* RLE: 006 Pixels @ 111,040*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,040*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,040*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,041*/ 1, 0x10, 0x84,
  /* RLE: 008 Pixels @ 003,041*/ 8, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 011,041*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 012,041*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 016,041*/ 1, 0xAE, 0xC3,
  /* RLE: 005 Pixels @ 017,041*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 022,041*/ 1, 0xD7, 0xE5,
  /* RLE: 004 Pixels @ 023,041*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 027,041*/ 1, 0x10, 0xCC,
  /* RLE: 004 Pixels @ 028,041*/ 4, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 032,041*/ 0, 6, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x86, 0x31,
  /* RLE: 004 Pixels @ 038,041*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 042,041*/ 0, 4, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42,
  /* RLE: 009 Pixels @ 046,041*/ 9, 0x00, 0x00,
  /* ABS: 005 Pixels @ 055,041*/ 0, 5, 0x8A, 0x52, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0x82, 0x10,
  /* RLE: 008 Pixels @ 060,041*/ 8, 0x00, 0x00,
  /* ABS: 006 Pixels @ 068,041*/ 0, 6, 0x82, 0x10, 0x79, 0xCE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C,
  /* RLE: 009 Pixels @ 074,041*/ 9, 0x00, 0x00,
  /* ABS: 005 Pixels @ 083,041*/ 0, 5, 0x82, 0x10, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84,
  /* RLE: 009 Pixels @ 088,041*/ 9, 0x00, 0x00,
  /* ABS: 003 Pixels @ 097,041*/ 0, 3, 0x04, 0x21, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 010 Pixels @ 100,041*/ 10, 0x00, 0x00,
  /* ABS: 002 Pixels @ 110,041*/ 0, 2, 0x82, 0x10, 0x7D, 0xEF,
  /* RLE: 005 Pixels @ 112,041*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,041*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,041*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,042*/ 1, 0x10, 0x84,
  /* RLE: 007 Pixels @ 003,042*/ 7, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 010,042*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 004 Pixels @ 017,042*/ 4, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 021,042*/ 0, 6, 0xBA, 0xEE, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0xCB, 0xBA,
  /* RLE: 005 Pixels @ 027,042*/ 5, 0xFF, 0xFF,
  /* ABS: 017 Pixels @ 032,042*/ 0, 17, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C,
  /* RLE: 006 Pixels @ 049,042*/ 6, 0xF7, 0xBD,
  /* ABS: 036 Pixels @ 055,042*/ 0, 36, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFB, 0xDE, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0x79, 0xCE, 0xFF, 0xFF, 0xFF, 0xFF, 0x71, 0x8C, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63,
  /* RLE: 006 Pixels @ 091,042*/ 6, 0xF7, 0xBD,
  /* ABS: 006 Pixels @ 097,042*/ 0, 6, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  /* RLE: 004 Pixels @ 103,042*/ 4, 0xF7, 0xBD,
  /* ABS: 005 Pixels @ 107,042*/ 0, 5, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 005 Pixels @ 112,042*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,042*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,042*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,043*/ 1, 0x10, 0x84,
  /* RLE: 007 Pixels @ 003,043*/ 7, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 010,043*/ 0, 6, 0x2C, 0xBB, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x1C, 0xF7,
  /* RLE: 004 Pixels @ 016,043*/ 4, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 020,043*/ 0, 7, 0x9E, 0xFF, 0x49, 0xB2, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x9E, 0xFF,
  /* RLE: 005 Pixels @ 027,043*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 032,043*/ 0, 4, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xF3, 0x9C,
  /* RLE: 004 Pixels @ 036,043*/ 4, 0xFF, 0xFF,
  /* ABS: 009 Pixels @ 040,043*/ 0, 9, 0x71, 0x8C, 0x10, 0x84, 0x79, 0xCE, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 008 Pixels @ 049,043*/ 8, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 057,043*/ 0, 5, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 062,043*/ 4, 0xFF, 0xFF,
  /* ABS: 011 Pixels @ 066,043*/ 0, 11, 0x79, 0xCE, 0x08, 0x42, 0x08, 0x42, 0x79, 0xCE, 0xFF, 0xFF, 0xFF, 0xFF, 0x8E, 0x73, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 077,043*/ 4, 0xFF, 0xFF,
  /* ABS: 010 Pixels @ 081,043*/ 0, 10, 0x79, 0xCE, 0x08, 0x42, 0x08, 0x42, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84,
  /* RLE: 009 Pixels @ 091,043*/ 9, 0xFF, 0xFF,
  /* RLE: 003 Pixels @ 100,043*/ 3, 0x00, 0x00,
  /* RLE: 005 Pixels @ 103,043*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 108,043*/ 0, 4, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 005 Pixels @ 112,043*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,043*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,043*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,044*/ 1, 0x10, 0x84,
  /* RLE: 006 Pixels @ 003,044*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 009,044*/ 1, 0xF3, 0xD4,
  /* RLE: 004 Pixels @ 010,044*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 014,044*/ 1, 0xD7, 0xE5,
  /* RLE: 005 Pixels @ 015,044*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 020,044*/ 1, 0xAE, 0xC3,
  /* RLE: 004 Pixels @ 021,044*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 025,044*/ 1, 0xBA, 0xEE,
  /* RLE: 006 Pixels @ 026,044*/ 6, 0xFF, 0xFF,
  /* ABS: 008 Pixels @ 032,044*/ 0, 8, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x0C, 0x63, 0x71, 0x8C, 0x79, 0xCE,
  /* RLE: 005 Pixels @ 040,044*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 045,044*/ 0, 4, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63,
  /* RLE: 005 Pixels @ 049,044*/ 5, 0x10, 0x84,
  /* ABS: 007 Pixels @ 054,044*/ 0, 7, 0xF3, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63,
  /* RLE: 011 Pixels @ 061,044*/ 11, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 072,044*/ 0, 4, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C,
  /* RLE: 011 Pixels @ 076,044*/ 11, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 087,044*/ 0, 4, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x08, 0x42,
  /* RLE: 005 Pixels @ 091,044*/ 5, 0x10, 0x84,
  /* ABS: 007 Pixels @ 096,044*/ 0, 7, 0x71, 0x8C, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  /* RLE: 004 Pixels @ 103,044*/ 4, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 107,044*/ 0, 5, 0xF7, 0xBD, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE,
  /* RLE: 005 Pixels @ 112,044*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,044*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,044*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,045*/ 1, 0x10, 0x84,
  /* RLE: 005 Pixels @ 003,045*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 008,045*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 009,045*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 013,045*/ 1, 0x10, 0xCC,
  /* RLE: 005 Pixels @ 014,045*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 019,045*/ 1, 0x55, 0xDD,
  /* RLE: 004 Pixels @ 020,045*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 024,045*/ 1, 0xF3, 0xD4,
  /* RLE: 007 Pixels @ 025,045*/ 7, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 032,045*/ 0, 2, 0x79, 0xCE, 0x04, 0x21,
  /* RLE: 006 Pixels @ 034,045*/ 6, 0x00, 0x00,
  /* ABS: 006 Pixels @ 040,045*/ 0, 6, 0x82, 0x10, 0x0C, 0x63, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42,
  /* RLE: 009 Pixels @ 046,045*/ 9, 0x00, 0x00,
  /* ABS: 010 Pixels @ 055,045*/ 0, 10, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84,
  /* RLE: 004 Pixels @ 065,045*/ 4, 0x08, 0x42,
  /* ABS: 011 Pixels @ 069,045*/ 0, 11, 0x0C, 0x63, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x8E, 0x73,
  /* RLE: 004 Pixels @ 080,045*/ 4, 0x08, 0x42,
  /* ABS: 004 Pixels @ 084,045*/ 0, 4, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84,
  /* RLE: 009 Pixels @ 088,045*/ 9, 0x00, 0x00,
  /* ABS: 003 Pixels @ 097,045*/ 0, 3, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 010 Pixels @ 100,045*/ 10, 0x00, 0x00,
  /* RLE: 001 Pixels @ 110,045*/ 1, 0x0C, 0x63,
  /* RLE: 006 Pixels @ 111,045*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,045*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,045*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,046*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 003,046*/ 4, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 007,046*/ 0, 6, 0x9E, 0xFF, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 005 Pixels @ 013,046*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 018,046*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 019,046*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 023,046*/ 1, 0xAE, 0xC3,
  /* RLE: 010 Pixels @ 024,046*/ 10, 0xFF, 0xFF,
  /* ABS: 003 Pixels @ 034,046*/ 0, 3, 0x75, 0xAD, 0x0C, 0x63, 0x86, 0x31,
  /* RLE: 005 Pixels @ 037,046*/ 5, 0x00, 0x00,
  /* ABS: 007 Pixels @ 042,046*/ 0, 7, 0x86, 0x31, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31,
  /* RLE: 005 Pixels @ 049,046*/ 5, 0x08, 0x42,
  /* ABS: 011 Pixels @ 054,046*/ 0, 11, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x82, 0x10,
  /* RLE: 005 Pixels @ 065,046*/ 5, 0x00, 0x00,
  /* ABS: 009 Pixels @ 070,046*/ 0, 9, 0xF7, 0xBD, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 006 Pixels @ 079,046*/ 6, 0x00, 0x00,
  /* ABS: 006 Pixels @ 085,046*/ 0, 6, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21,
  /* RLE: 005 Pixels @ 091,046*/ 5, 0x08, 0x42,
  /* ABS: 004 Pixels @ 096,046*/ 0, 4, 0x0C, 0x63, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF,
  /* RLE: 009 Pixels @ 100,046*/ 9, 0x00, 0x00,
  /* ABS: 002 Pixels @ 109,046*/ 0, 2, 0x82, 0x10, 0xF3, 0x9C,
  /* RLE: 006 Pixels @ 111,046*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,046*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,046*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,047*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 003,047*/ 4, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 007,047*/ 0, 6, 0xCB, 0xBA, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0x1C, 0xF7,
  /* RLE: 004 Pixels @ 013,047*/ 4, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 017,047*/ 0, 7, 0x9E, 0xFF, 0xE7, 0xA9, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2, 0x9E, 0xFF,
  /* RLE: 008 Pixels @ 024,047*/ 8, 0xFF, 0xFF,
  /* ABS: 017 Pixels @ 032,047*/ 0, 17, 0x7D, 0xEF, 0xF7, 0xBD, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x75, 0xAD, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 008 Pixels @ 049,047*/ 8, 0xFF, 0xFF,
  /* ABS: 034 Pixels @ 057,047*/ 0, 34, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0x8A, 0x52, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x10, 0x84, 0x10, 0x84, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00,
        0x00, 0x00, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x10, 0x84, 0x10, 0x84, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84,
  /* RLE: 009 Pixels @ 091,047*/ 9, 0xFF, 0xFF,
  /* RLE: 003 Pixels @ 100,047*/ 3, 0x00, 0x00,
  /* RLE: 003 Pixels @ 103,047*/ 3, 0xF7, 0xBD,
  /* ABS: 005 Pixels @ 106,047*/ 0, 5, 0x75, 0xAD, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10,
  /* RLE: 006 Pixels @ 111,047*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,047*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,047*/ 4, 0x00, 0x00,
  /* ABS: 005 Pixels @ 002,048*/ 0, 5, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x92, 0xD4,
  /* RLE: 004 Pixels @ 007,048*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 011,048*/ 1, 0xD7, 0xE5,
  /* RLE: 005 Pixels @ 012,048*/ 5, 0xFF, 0xFF,
  /* ABS: 006 Pixels @ 017,048*/ 0, 6, 0xCB, 0xBA, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x65, 0xA1, 0xBA, 0xEE,
  /* RLE: 009 Pixels @ 023,048*/ 9, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 032,048*/ 0, 4, 0x8A, 0x52, 0x00, 0x00, 0x82, 0x10, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 036,048*/ 4, 0xFF, 0xFF,
  /* ABS: 009 Pixels @ 040,048*/ 0, 9, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 008 Pixels @ 049,048*/ 8, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 057,048*/ 0, 5, 0xF3, 0x9C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD,
  /* RLE: 004 Pixels @ 062,048*/ 4, 0xFF, 0xFF,
  /* ABS: 011 Pixels @ 066,048*/ 0, 11, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x79, 0xCE,
  /* RLE: 004 Pixels @ 077,048*/ 4, 0xFF, 0xFF,
  /* ABS: 010 Pixels @ 081,048*/ 0, 10, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84,
  /* RLE: 009 Pixels @ 091,048*/ 9, 0xFF, 0xFF,
  /* RLE: 003 Pixels @ 100,048*/ 3, 0x00, 0x00,
  /* RLE: 004 Pixels @ 103,048*/ 4, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 107,048*/ 0, 4, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  /* RLE: 006 Pixels @ 111,048*/ 6, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,048*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,048*/ 4, 0x00, 0x00,
  /* ABS: 009 Pixels @ 002,049*/ 0, 9, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x10, 0xCC,
  /* RLE: 005 Pixels @ 011,049*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 016,049*/ 1, 0xBA, 0xEE,
  /* RLE: 004 Pixels @ 017,049*/ 4, 0x04, 0xA1,
  /* RLE: 001 Pixels @ 021,049*/ 1, 0x55, 0xDD,
  /* RLE: 010 Pixels @ 022,049*/ 10, 0xFF, 0xFF,
  /* ABS: 017 Pixels @ 032,049*/ 0, 17, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0x75, 0xAD, 0xF7, 0xBD, 0xF7, 0xBD, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63,
  /* RLE: 006 Pixels @ 049,049*/ 6, 0x10, 0x84,
  /* ABS: 026 Pixels @ 055,049*/ 0, 26, 0xF3, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x8E, 0x73, 0xF7, 0xBD, 0xF7, 0xBD, 0x10, 0x84, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF,
        0x7D, 0xEF, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x8E, 0x73, 0xF7, 0xBD, 0xF7, 0xBD, 0x8E, 0x73,
  /* RLE: 004 Pixels @ 081,049*/ 4, 0x00, 0x00,
  /* ABS: 006 Pixels @ 085,049*/ 0, 6, 0xFF, 0xFF, 0xFF, 0xFF, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x08, 0x42,
  /* RLE: 006 Pixels @ 091,049*/ 6, 0x10, 0x84,
  /* ABS: 006 Pixels @ 097,049*/ 0, 6, 0x71, 0x8C, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  /* RLE: 005 Pixels @ 103,049*/ 5, 0xFF, 0xFF,
  /* RLE: 003 Pixels @ 108,049*/ 3, 0x00, 0x00,
  /* RLE: 001 Pixels @ 111,049*/ 1, 0xFB, 0xDE,
  /* RLE: 005 Pixels @ 112,049*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,049*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,049*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,050*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCB, 0xBA, 0x04, 0xA1, 0x04, 0xA1, 0x49, 0xB2,
  /* RLE: 006 Pixels @ 010,050*/ 6, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 016,050*/ 0, 5, 0x9E, 0xFF, 0x65, 0xA1, 0x04, 0xA1, 0x04, 0xA1, 0x10, 0xCC,
  /* RLE: 011 Pixels @ 021,050*/ 11, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 032,050*/ 0, 2, 0x79, 0xCE, 0x82, 0x10,
  /* RLE: 008 Pixels @ 034,050*/ 8, 0x00, 0x00,
  /* ABS: 004 Pixels @ 042,050*/ 0, 4, 0x0C, 0x63, 0xFF, 0xFF, 0xFF, 0xFF, 0x8A, 0x52,
  /* RLE: 010 Pixels @ 046,050*/ 10, 0x00, 0x00,
  /* ABS: 004 Pixels @ 056,050*/ 0, 4, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x86, 0x31,
  /* RLE: 007 Pixels @ 060,050*/ 7, 0x00, 0x00,
  /* ABS: 008 Pixels @ 067,050*/ 0, 8, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0x04, 0x21,
  /* RLE: 007 Pixels @ 075,050*/ 7, 0x00, 0x00,
  /* ABS: 006 Pixels @ 082,050*/ 0, 6, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x71, 0x8C,
  /* RLE: 010 Pixels @ 088,050*/ 10, 0x00, 0x00,
  /* ABS: 005 Pixels @ 098,050*/ 0, 5, 0xF7, 0xBD, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  /* RLE: 005 Pixels @ 103,050*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 108,050*/ 0, 4, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 005 Pixels @ 112,050*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,050*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,050*/ 4, 0x00, 0x00,
  /* ABS: 008 Pixels @ 002,051*/ 0, 8, 0x10, 0x84, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x9E, 0xFF, 0x92, 0xD4, 0x92, 0xD4, 0x9E, 0xFF,
  /* RLE: 007 Pixels @ 010,051*/ 7, 0xFF, 0xFF,
  /* ABS: 003 Pixels @ 017,051*/ 0, 3, 0xBA, 0xEE, 0x92, 0xD4, 0xF3, 0xD4,
  /* RLE: 013 Pixels @ 020,051*/ 13, 0xFF, 0xFF,
  /* ABS: 003 Pixels @ 033,051*/ 0, 3, 0xFB, 0xDE, 0x0C, 0x63, 0x82, 0x10,
  /* RLE: 004 Pixels @ 036,051*/ 4, 0x00, 0x00,
  /* ABS: 006 Pixels @ 040,051*/ 0, 6, 0x86, 0x31, 0xF3, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE,
  /* RLE: 009 Pixels @ 046,051*/ 9, 0x08, 0x42,
  /* ABS: 034 Pixels @ 055,051*/ 0, 34, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x10, 0x84, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x8E, 0x73, 0x7D, 0xEF, 0x82, 0x10, 0x00, 0x00, 0xFB, 0xDE, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x10, 0x84, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x10, 0x84, 0xFB, 0xDE, 0x82, 0x10, 0x82, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xDE, 0x8A, 0x52,
  /* RLE: 008 Pixels @ 089,051*/ 8, 0x08, 0x42,
  /* ABS: 006 Pixels @ 097,051*/ 0, 6, 0x8A, 0x52, 0x7D, 0xEF, 0xFF, 0xFF, 0x0C, 0x63, 0x00, 0x00, 0x08, 0x42,
  /* RLE: 005 Pixels @ 103,051*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 108,051*/ 0, 4, 0x10, 0x84, 0x00, 0x00, 0x04, 0x21, 0xFB, 0xDE,
  /* RLE: 005 Pixels @ 112,051*/ 5, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,051*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,051*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,052*/ 1, 0x10, 0x84,
  /* RLE: 114 Pixels @ 003,052*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,052*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,052*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,053*/ 1, 0x10, 0x84,
  /* RLE: 114 Pixels @ 003,053*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,053*/ 1, 0x10, 0x84,
  /* RLE: 004 Pixels @ 118,053*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,054*/ 1, 0x8E, 0x73,
  /* RLE: 114 Pixels @ 003,054*/ 114, 0xFF, 0xFF,
  /* RLE: 001 Pixels @ 117,054*/ 1, 0x8E, 0x73,
  /* RLE: 004 Pixels @ 118,054*/ 4, 0x00, 0x00,
  /* RLE: 001 Pixels @ 002,055*/ 1, 0x86, 0x31,
  /* RLE: 114 Pixels @ 003,055*/ 114, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 117,055*/ 0, 7, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0x10, 0x84,
  /* RLE: 112 Pixels @ 004,056*/ 112, 0xFF, 0xFF,
  /* ABS: 005 Pixels @ 116,056*/ 0, 5, 0x10, 0x84, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x75, 0xAD,
  /* RLE: 118 Pixels @ 001,057*/ 118, 0x00, 0x00,
  /* ABS: 003 Pixels @ 119,057*/ 0, 3, 0x75, 0xAD, 0xFF, 0xFF, 0x8E, 0x73,
  /* RLE: 116 Pixels @ 002,058*/ 116, 0x00, 0x00,
  /* ABS: 006 Pixels @ 118,058*/ 0, 6, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0x0C, 0x63,
  /* RLE: 112 Pixels @ 004,059*/ 112, 0x08, 0x42,
  /* ABS: 002 Pixels @ 116,059*/ 0, 2, 0x0C, 0x63, 0xF7, 0xBD,
  /* RLE: 122 Pixels @ 118,059*/ 122, 0xFF, 0xFF,
  /* ABS: 035 Pixels @ 000,061*/ 0, 35, 0x79, 0xCE, 0xEF, 0x7B, 0x7D, 0xEF, 0xFF, 0xFF, 0xFB, 0xDE, 0xEF, 0x7B, 0xF3, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x71, 0x8C, 0xFF, 0xFF, 0x71, 0x8C, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD,
        0xEF, 0x7B, 0x79, 0xCE, 0xFF, 0xFF, 0x7D, 0xEF, 0xEF, 0x7B, 0xF7, 0xBD, 0x79, 0xCE, 0xEF, 0x7B, 0xFB, 0xDE, 0xFF, 0xFF, 0x7D, 0xEF, 0xEF, 0x7B, 0x71, 0x8C, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x71, 0x8C, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 035,061*/ 4, 0xFF, 0xFF,
  /* ABS: 049 Pixels @ 039,061*/ 0, 49, 0xFB, 0xDE, 0x71, 0x8C, 0xEF, 0x7B, 0xEF, 0x7B, 0x71, 0x8C, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFB, 0xDE, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xFB, 0xDE, 0x71, 0x8C, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x71, 0x8C, 0xEF, 0x7B, 0xEF, 0x7B, 0x79, 0xCE, 0x71, 0x8C, 0x71, 0x8C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD,
        0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0xEF, 0x7B, 0x79, 0xCE, 0xF7, 0xBD, 0xEF, 0x7B, 0xFB, 0xDE,
  /* RLE: 004 Pixels @ 088,061*/ 4, 0xFF, 0xFF,
  /* ABS: 068 Pixels @ 092,061*/ 0, 68, 0xFB, 0xDE, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0xF3, 0x9C, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF,
        0xEF, 0x7B, 0x79, 0xCE, 0x75, 0xAD, 0xEF, 0x7B, 0xEF, 0x7B, 0xF7, 0xBD, 0xFB, 0xDE, 0xEF, 0x7B, 0xEF, 0x7B, 0x71, 0x8C, 0x7D, 0xEF, 0x08, 0x42, 0x00, 0x00, 0x0C, 0x63, 0xFF, 0xFF, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0xFF, 0xFF,
        0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xDE, 0xFB, 0xDE, 0x00, 0x00, 0x00, 0x00, 0x8A, 0x52, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0x8A, 0x52, 0x00, 0x00, 0x0C, 0x63, 0xFF, 0xFF, 0x0C, 0x63, 0x00, 0x00,
        0x00, 0x00, 0x79, 0xCE, 0xFF, 0xFF, 0x82, 0x10, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xDE, 0x82, 0x10,
  /* RLE: 004 Pixels @ 040,062*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 044,062*/ 0, 4, 0x82, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0x0C, 0x63,
  /* RLE: 005 Pixels @ 048,062*/ 5, 0x00, 0x00,
  /* ABS: 004 Pixels @ 053,062*/ 0, 4, 0xF3, 0x9C, 0xFF, 0xFF, 0xFB, 0xDE, 0x82, 0x10,
  /* RLE: 006 Pixels @ 057,062*/ 6, 0x00, 0x00,
  /* ABS: 012 Pixels @ 063,062*/ 0, 12, 0xFF, 0xFF, 0x7D, 0xEF, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0x0C, 0x63,
  /* RLE: 005 Pixels @ 075,062*/ 5, 0x00, 0x00,
  /* ABS: 012 Pixels @ 080,062*/ 0, 12, 0xF3, 0x9C, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C,
  /* RLE: 005 Pixels @ 092,062*/ 5, 0x00, 0x00,
  /* ABS: 004 Pixels @ 097,062*/ 0, 4, 0x8E, 0x73, 0xFF, 0xFF, 0xFB, 0xDE, 0x04, 0x21,
  /* RLE: 004 Pixels @ 101,062*/ 4, 0x00, 0x00,
  /* ABS: 004 Pixels @ 105,062*/ 0, 4, 0x82, 0x10, 0x75, 0xAD, 0xFF, 0xFF, 0xEF, 0x7B,
  /* RLE: 006 Pixels @ 109,062*/ 6, 0x00, 0x00,
  /* ABS: 159 Pixels @ 115,062*/ 0, 159, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x42, 0x8E, 0x73, 0x00, 0x00, 0x04, 0x21, 0xFF, 0xFF, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0x7D, 0xEF,
        0x00, 0x00, 0x00, 0x00, 0xF3, 0x9C, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x8E, 0x73, 0x71, 0x8C, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0xF7, 0xBD,
        0x00, 0x00, 0x00, 0x00, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x82, 0x10, 0xF7, 0xBD, 0x75, 0xAD, 0x04, 0x21, 0x82, 0x10, 0xFF, 0xFF, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63, 0xF7, 0xBD, 0x08, 0x42,
        0x00, 0x00, 0x82, 0x10, 0x7D, 0xEF, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xF3, 0x9C, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0x75, 0xAD, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00,
        0xF7, 0xBD, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x8E, 0x73, 0xF7, 0xBD, 0x86, 0x31, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x08, 0x42, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x82, 0x10,
        0x00, 0x00, 0x86, 0x31, 0x75, 0xAD, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x8A, 0x52, 0x00, 0x00, 0x82, 0x10, 0xF3, 0x9C, 0x75, 0xAD, 0x86, 0x31, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B,
        0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0xF3, 0x9C, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63, 0x8E, 0x73, 0x00, 0x00, 0x8A, 0x52, 0xFF, 0xFF,
        0x8A, 0x52, 0x00, 0x00, 0x8A, 0x52, 0x8E, 0x73, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0x00, 0x00, 0x82, 0x10, 0x00, 0x00, 0x8A, 0x52, 0xEF, 0x7B,
        0x00, 0x00, 0x08, 0x42,
  /* RLE: 004 Pixels @ 034,064*/ 4, 0xFF, 0xFF,
  /* ABS: 048 Pixels @ 038,064*/ 0, 48, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x8A, 0x52, 0x71, 0x8C, 0xFB, 0xDE, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xEF, 0x7B, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
        0x82, 0x10, 0x00, 0x00, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x86, 0x31, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xEF, 0x7B, 0x00, 0x00,
        0x00, 0x00, 0xEF, 0x7B, 0xEF, 0x7B, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xEF, 0x7B, 0x00, 0x00, 0x82, 0x10, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 086,064*/ 4, 0xFF, 0xFF,
  /* ABS: 064 Pixels @ 090,064*/ 0, 64, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0x71, 0x8C, 0x75, 0xAD, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x8E, 0x73, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00,
        0xF7, 0xBD, 0xEF, 0x7B, 0x00, 0x00, 0x04, 0x21, 0xFF, 0xFF, 0xFF, 0xFF, 0x86, 0x31, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x04, 0x21, 0x00, 0x00, 0x0C, 0x63, 0x00, 0x00, 0xEF, 0x7B, 0x00, 0x00,
        0x04, 0x21, 0x86, 0x31, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF, 0xF3, 0x9C, 0x00, 0x00, 0x82, 0x10, 0x08, 0x42, 0x00, 0x00, 0xEF, 0x7B, 0x00, 0x00, 0x0C, 0x63, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0x04, 0x21, 0x00, 0x00, 0x8A, 0x52,
        0x00, 0x00, 0x8E, 0x73, 0x82, 0x10, 0x82, 0x10, 0x08, 0x42, 0x00, 0x00, 0x71, 0x8C,
  /* RLE: 004 Pixels @ 034,065*/ 4, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 038,065*/ 0, 2, 0x7D, 0xEF, 0x0C, 0x63,
  /* RLE: 005 Pixels @ 040,065*/ 5, 0x00, 0x00,
  /* ABS: 002 Pixels @ 045,065*/ 0, 2, 0x75, 0xAD, 0xEF, 0x7B,
  /* RLE: 007 Pixels @ 047,065*/ 7, 0x00, 0x00,
  /* ABS: 020 Pixels @ 054,065*/ 0, 20, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0xFF, 0xFF, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00,
        0x00, 0x00, 0xF7, 0xBD, 0xEF, 0x7B,
  /* RLE: 007 Pixels @ 074,065*/ 7, 0x00, 0x00,
  /* ABS: 004 Pixels @ 081,065*/ 0, 4, 0x79, 0xCE, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42,
  /* RLE: 005 Pixels @ 085,065*/ 5, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 090,065*/ 0, 4, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD,
  /* RLE: 005 Pixels @ 094,065*/ 5, 0xFF, 0xFF,
  /* ABS: 255 Pixels @ 099,065*/ 0, 255, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0xEF, 0x7B,
        0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xDE, 0xFF, 0xFF, 0x7D, 0xEF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x86, 0x31, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63, 0xFF, 0xFF, 0xFF, 0xFF, 0x8E, 0x73, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xDE, 0xFF, 0xFF, 0xF7, 0xBD,
        0xFB, 0xDE, 0xFF, 0xFF, 0x79, 0xCE, 0xEF, 0x7B, 0xF7, 0xBD, 0x75, 0xAD, 0x8E, 0x73, 0x82, 0x10, 0x00, 0x00, 0x08, 0x42, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C, 0xF7, 0xBD, 0xFF, 0xFF, 0x04, 0x21,
        0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0x8A, 0x52, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x8A, 0x52, 0x00, 0x00, 0x04, 0x21, 0x7D, 0xEF, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00,
        0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C, 0x79, 0xCE, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xDE, 0x79, 0xCE, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xF3, 0x9C, 0xFF, 0xFF, 0x7D, 0xEF,
        0x8A, 0x52, 0x8A, 0x52, 0xFF, 0xFF, 0x82, 0x10, 0x00, 0x00, 0x0C, 0x63, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C, 0x00, 0x00, 0x00, 0x00, 0x79, 0xCE, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0xEF, 0x7B,
        0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00,
        0x8E, 0x73, 0xFF, 0xFF, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7D, 0xEF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0xFF, 0xFF, 0x8E, 0x73, 0x00, 0x00,
        0x82, 0x10, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x82, 0x10, 0xEF, 0x7B, 0x71, 0x8C, 0x82, 0x10, 0x00, 0x00, 0x8A, 0x52, 0xFB, 0xDE, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0xEF, 0x7B, 0x08, 0x42, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xEF, 0x7B,
        0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x86, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFB, 0xDE, 0x00, 0x00, 0x00, 0x00,
        0x86, 0x31, 0xEF, 0x7B, 0x08, 0x42, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFB, 0xDE, 0x00, 0x00, 0x00, 0x00, 0xF3, 0x9C, 0xFF, 0xFF, 0x82, 0x10, 0x00, 0x00, 0x82, 0x10, 0x8E, 0x73, 0x04, 0x21,
        0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0x0C, 0x63, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x63, 0x8E, 0x73, 0x82, 0x10, 0x00, 0x00, 0x04, 0x21, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42,
  /* ABS: 027 Pixels @ 114,067*/ 0, 27, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x82, 0x10, 0x00, 0x00, 0x86, 0x31, 0xFF, 0xFF, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF,
        0xFF, 0xFF, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x75, 0xAD, 0xFF, 0xFF, 0x8A, 0x52, 0x00, 0x00, 0x82, 0x10,
  /* RLE: 004 Pixels @ 021,068*/ 4, 0xFF, 0xFF,
  /* ABS: 015 Pixels @ 025,068*/ 0, 15, 0x82, 0x10, 0x00, 0x00, 0x86, 0x31, 0xFF, 0xFF, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0xEF, 0x7B, 0xFF, 0xFF, 0x8E, 0x73, 0x00, 0x00, 0x82, 0x10, 0xFF, 0xFF, 0x79, 0xCE, 0x82, 0x10,
  /* RLE: 004 Pixels @ 040,068*/ 4, 0x00, 0x00,
  /* ABS: 031 Pixels @ 044,068*/ 0, 31, 0x04, 0x21, 0x79, 0xCE, 0xFF, 0xFF, 0xF3, 0x9C, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x82, 0x10, 0xF3, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0x8E, 0x73, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31,
        0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF3, 0x9C, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x00, 0x00, 0x00, 0x00, 0xF7, 0xBD, 0xFF, 0xFF, 0xF3, 0x9C,
  /* RLE: 004 Pixels @ 075,068*/ 4, 0x00, 0x00,
  /* ABS: 022 Pixels @ 079,068*/ 0, 22, 0x82, 0x10, 0x79, 0xCE, 0xFF, 0xFF, 0xEF, 0x7B, 0x00, 0x00, 0x8A, 0x52, 0xFF, 0xFF, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF, 0x79, 0xCE, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
        0x82, 0x10, 0x75, 0xAD, 0xFF, 0xFF, 0x7D, 0xEF, 0x08, 0x42,
  /* RLE: 004 Pixels @ 101,068*/ 4, 0x00, 0x00,
  /* ABS: 024 Pixels @ 105,068*/ 0, 24, 0x04, 0x21, 0x79, 0xCE, 0xFF, 0xFF, 0x71, 0x8C, 0x00, 0x00, 0x08, 0x42, 0xFF, 0xFF, 0xFF, 0xFF, 0x08, 0x42, 0x00, 0x00, 0x71, 0x8C, 0xFF, 0xFF, 0x79, 0xCE, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF,
        0xFB, 0xDE, 0xF7, 0xBD, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0xF7, 0xBD,
  /* RLE: 005 Pixels @ 009,069*/ 5, 0xFF, 0xFF,
  /* ABS: 007 Pixels @ 014,069*/ 0, 7, 0xF7, 0xBD, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0xF7, 0xBD, 0xFB, 0xDE,
  /* RLE: 004 Pixels @ 021,069*/ 4, 0xFF, 0xFF,
  /* ABS: 019 Pixels @ 025,069*/ 0, 19, 0xFB, 0xDE, 0xF7, 0xBD, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBD, 0xEF, 0x7B,
        0x71, 0x8C, 0xF7, 0xBD,
  /* RLE: 004 Pixels @ 044,069*/ 4, 0xFF, 0xFF,
  /* ABS: 049 Pixels @ 048,069*/ 0, 49, 0x7D, 0xEF, 0x75, 0xAD, 0xEF, 0x7B, 0xF7, 0xBD, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0xEF, 0x7B, 0x75, 0xAD, 0xF7, 0xBD, 0x7D, 0xEF, 0xEF, 0x7B, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0x7D, 0xEF,
        0xEF, 0x7B, 0x71, 0x8C, 0x79, 0xCE, 0xFB, 0xDE, 0x75, 0xAD, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xDE, 0x75, 0xAD, 0xEF, 0x7B, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0xF7, 0xBD, 0xFB, 0xDE,
        0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xEF, 0x75, 0xAD, 0xEF, 0x7B, 0x75, 0xAD, 0x7D, 0xEF,
  /* RLE: 004 Pixels @ 097,069*/ 4, 0xFF, 0xFF,
  /* ABS: 004 Pixels @ 101,069*/ 0, 4, 0x79, 0xCE, 0xF3, 0x9C, 0x71, 0x8C, 0xF7, 0xBD,
  /* RLE: 004 Pixels @ 105,069*/ 4, 0xFF, 0xFF,
  /* ABS: 011 Pixels @ 109,069*/ 0, 11, 0xF7, 0xBD, 0xFB, 0xDE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB, 0xDE, 0xF7, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x79, 0xCE, 0x79, 0xCE,
  /* RLE: 055 Pixels @ 000,070*/ 55, 0xFF, 0xFF,
  /* ABS: 017 Pixels @ 055,070*/ 0, 17, 0x71, 0x8C, 0x00, 0x00, 0x00, 0x00, 0x86, 0x31, 0x08, 0x42, 0x00, 0x00, 0x00, 0x00, 0x8A, 0x52, 0xFF, 0xFF, 0xF7, 0xBD, 0x00, 0x00, 0x00, 0x00, 0x04, 0x21, 0x08, 0x42, 0x82, 0x10, 0x00, 0x00, 0x04, 0x21,
  /* RLE: 103 Pixels @ 072,070*/ 103, 0xFF, 0xFF,
  /* ABS: 002 Pixels @ 055,071*/ 0, 2, 0x7D, 0xEF, 0x0C, 0x63,
  /* RLE: 004 Pixels @ 057,071*/ 4, 0x00, 0x00,
  /* ABS: 011 Pixels @ 061,071*/ 0, 11, 0x8A, 0x52, 0x7D, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0x8E, 0x73, 0x82, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x42, 0x79, 0xCE,
  /* RLE: 048 Pixels @ 072,071*/ 48, 0xFF, 0xFF,


  0};  /* 3403 for 8640 pixels */

GUI_CONST_STORAGE GUI_BITMAP bmSeggerLogo120 = {
  120, /* XSize */
  72, /* YSize */
  240, /* BytesPerLine */
  16, /* BitsPerPixel */
  (unsigned char *)acSeggerLogo120,  /* Pointer to picture data */
  NULL  /* Pointer to palette */
 ,GUI_DRAW_RLE16
};


static const char * _ListViewDummyTaskList[][5] = {
  { "", "", "", "", "" }
};

static const char * _ListViewDummySystemVariables[][2] = {
  { "", "" }
};

char _acBuffer[64];

/*********************************************************************
*
*       main()
*/
void MainTask(void);
void MainTask(void) {
  OS_TASK *pTask;
  WM_HWIN hFrameTaskList;
  WM_HWIN hFrameSystemVariables;
  WM_HWIN hListViewSystemVariables;
  WM_HWIN hListViewTaskList;
  U8 NumRows;
  int i;
  GUI_Init();
  GUI_CURSOR_Show();
#if GUI_SUPPORT_MEMDEV
  WM_SetCreateFlags(WM_CF_MEMDEV);
#endif
  HEADER_SetDefaultFont(&GUI_Font6x8);
  HEADER_SetDefaultBkColor(GUI_LIGHTGRAY);
  LISTVIEW_SetDefaultFont(&GUI_Font6x8);
  hFrameSystemVariables    = FRAMEWIN_CreateEx(0, 0    , 160, 120, 0, WM_CF_SHOW, 0, 0, "System variables", 0);
  hFrameTaskList           = FRAMEWIN_CreateEx(0, 120  , 320, 120, 0, WM_CF_SHOW, 0, 0, "Task list"       , 0);
  hListViewSystemVariables = LISTVIEW_CreateAttached(WM_GetClientWindow(hFrameSystemVariables), 0, 0);
  hListViewTaskList        = LISTVIEW_CreateAttached(WM_GetClientWindow(hFrameTaskList)       , 0, 0);
  LISTVIEW_SetGridVis(hListViewTaskList,        1);
  LISTVIEW_SetGridVis(hListViewSystemVariables, 1);
  LISTVIEW_AddColumn(hListViewSystemVariables , 50  , "Name"       , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewSystemVariables , 110 , "Value"      , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewTaskList        , 65  , "ID"         , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewTaskList        , 25  , "Pri"        , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewTaskList        , 65  , "Task name"  , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewTaskList        , 40  , "Activ."     , GUI_TA_LEFT);
  LISTVIEW_AddColumn(hListViewTaskList        , 120 , "Task stack" , GUI_TA_LEFT);
  LISTVIEW_SetTextAlign(hListViewTaskList, 6, GUI_TA_RIGHT);
  for (i = 0; i < 4; i++) {
    LISTVIEW_AddRow(hListViewSystemVariables, _ListViewDummySystemVariables[0]);
  }
  LISTVIEW_SetItemText(hListViewSystemVariables, 0, 0, "NumTasks");
  LISTVIEW_SetItemText(hListViewSystemVariables, 0, 1, "OS_Time");
  LISTVIEW_SetItemText(hListViewSystemVariables, 0, 2, "SysStack");
  LISTVIEW_SetItemText(hListViewSystemVariables, 0, 3, "IntStack");

  GUI_SetColor(GUI_WHITE);
  GUI_FillRect(160,0,320,120);
  GUI_DrawBitmap(&bmSeggerLogo120,180,20);

  while(1) {
    sprintf(_acBuffer, "%i", OS_GetNumTasks());
    LISTVIEW_SetItemText(hListViewSystemVariables, 1, 0, _acBuffer);
    sprintf(_acBuffer, "%i", OS_GetTime32());
    LISTVIEW_SetItemText(hListViewSystemVariables, 1, 1, _acBuffer);
#if OS_CHECKSTACK
#if OS_SUPPORT_SYSSTACK_INFO
    sprintf(_acBuffer, "%u@0x%.8X", OS_GetSysStackSize(), OS_GetSysStackBase());
    LISTVIEW_SetItemText(hListViewSystemVariables, 1, 2, _acBuffer);
#endif
#if OS_SUPPORT_INTSTACK_INFO
    sprintf(_acBuffer, "%u@0x%.8X", OS_GetIntStackSize(), OS_GetIntStackBase());
    LISTVIEW_SetItemText(hListViewSystemVariables, 1, 3, _acBuffer);
#endif
#endif
    NumRows = LISTVIEW_GetNumRows(hListViewTaskList);
    if (NumRows > 0) {
      for (i = (NumRows - 1); i >= 0; i--) {
        LISTVIEW_DeleteRow(hListViewTaskList, i);
      }
    }
    i = 0;  // Row counter
    for (pTask = OS_Global.pTask; pTask; pTask = pTask->pNext) {
      LISTVIEW_AddRow(hListViewTaskList, _ListViewDummyTaskList[0]);
      sprintf(_acBuffer, "0x%.8X", pTask);
      LISTVIEW_SetItemText(hListViewTaskList, 0, i, _acBuffer);
      sprintf(_acBuffer, "%i", OS_GetPriority(pTask));
      LISTVIEW_SetItemText(hListViewTaskList, 1, i, _acBuffer);
      LISTVIEW_SetItemText(hListViewTaskList, 2, i, OS_GetTaskName(pTask));
      sprintf(_acBuffer, "%u", OS_STAT_GetNumActivations(pTask));
      LISTVIEW_SetItemText(hListViewTaskList, 3, i, _acBuffer);
      sprintf(_acBuffer, "%u/%u@0x%u", OS_GetStackUsed(pTask), OS_GetStackSize(pTask), OS_GetStackBase(pTask));
      LISTVIEW_SetItemText(hListViewTaskList, 4, i, _acBuffer);
      i++;
    }
    GUI_Delay(500);
  }
}

/****** End of File *************************************************/
