/*********************************************************************
*                SEGGER MICROCONTROLLER GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 2003-2014     SEGGER Microcontroller GmbH & Co KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for the ST STM32F4x9I_EVAL board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"
#include "stm32f4xx.h"                // Device specific header file, contains CMSIS
#include "stm324x9i_eval_fmc_sdram.h" // Device specific header file, contains SDRAM_Init()

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define GPIOA_BASE_ADDR           ((unsigned int)0x40020000)
#define GPIOA_MODER               (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00))
#define GPIOA_AFRL                (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x20))
#define GPIOA_AFRH                (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x24))

#define GPIOB_BASE_ADDR           ((unsigned int)0x40020400)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00))
#define GPIOB_AFRL                (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x20))
#define GPIOB_AFRH                (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x24))

#define GPIOC_BASE_ADDR           ((unsigned int)0x40020800)
#define GPIOC_MODER               (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x00))
#define GPIOC_AFRL                (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x20))
#define GPIOC_AFRH                (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x24))

#define GPIOG_BASE_ADDR           ((unsigned int)0x40021800)
#define GPIOG_MODER               (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x00))
#define GPIOG_OSPEEDR             (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x08))
#define GPIOG_AFRL                (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x20))
#define GPIOG_AFRH                (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x24))

#define GPIOH_BASE_ADDR           ((unsigned int)0x40021C00)
#define GPIOH_MODER               (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x00))
#define GPIOH_AFRL                (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x20))
#define GPIOH_AFRH                (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x24))

#define GPIOI_BASE_ADDR           ((unsigned int)0x40022000)
#define GPIOI_MODER               (*(volatile unsigned int*)(GPIOI_BASE_ADDR + 0x00))
#define GPIOI_AFRL                (*(volatile unsigned int*)(GPIOI_BASE_ADDR + 0x20))
#define GPIOI_AFRH                (*(volatile unsigned int*)(GPIOI_BASE_ADDR + 0x24))

#define RCC_BASE_ADDR             ((unsigned int)(0x40023800))
#define RCC_AHB1RSTR              (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x10))
#define RCC_AHBENR                (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30))
#define RCC_LEDPORT_BITS          (1u << 6u)

#define GPIOG_BASE_ADDR           ((unsigned int)0x40021800)
#define GPIOG_MODER               (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x00))
#define GPIOG_ODR                 (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x14))

#define LED0_BIT                  (6u)  // LED1 - PG6
#define LED1_BIT                  (7u)  // LED2 - PG7


/*********************************************************************
*
*       Typedefs
*
**********************************************************************
*/
typedef void USB_ISR_HANDLER  (void);

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static USB_ISR_HANDLER * _pfUSBISRHandler;

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initialize port for LEDs (sample application)
  //
  RCC_AHBENR   &= ~RCC_LEDPORT_BITS;
  RCC_AHB1RSTR &= ~RCC_LEDPORT_BITS;
  RCC_AHBENR   |=  RCC_LEDPORT_BITS;

  GPIOG_MODER &= ~(3u << (LED0_BIT * 2));   // Reset mode; sets port to input
  GPIOG_MODER |=  (1u << (LED0_BIT * 2));   // Set to output mode
  GPIOG_ODR   &= ~(1u << LED0_BIT);         // Initially clear LEDs, low active

  GPIOG_MODER &= ~(3u << (LED1_BIT * 2));   // Reset mode; sets port to input
  GPIOG_MODER |=  (1u << (LED1_BIT * 2));   // Set to output mode
  GPIOG_ODR   &= ~(1u << LED1_BIT);         // Initially clear LEDs, low active
    
  SDRAM_Init();
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOG_ODR &= ~(1u << LED0_BIT);         // Switch on LED0
  } else if (Index == 1) {
    GPIOG_ODR &= ~(1u << LED1_BIT);         // Switch on LED1
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOG_ODR |= (1u << LED0_BIT);          // Switch off LED0
  } else if (Index == 1) {
    GPIOG_ODR |= (1u << LED1_BIT);          // Switch off LED1
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOG_ODR ^= (1u << LED0_BIT);          // Toggle LED0
  } else if (Index == 1) {
    GPIOG_ODR ^= (1u << LED1_BIT);          // Toggle LED1
  }
}


/*********************************************************************
*
*       USB
*
*  Functions for USB controllers (as far as present)
*/

/****** Declare ISR handler here to avoid "no prototype" warning. They are not declared in any CMSIS header */

#ifdef __cplusplus
extern "C" {
#endif
void OTG_FS_IRQHandler(void);
void OTG_HS_IRQHandler(void);
#ifdef __cplusplus
}
#endif

/*********************************************************************
*
*       OTG_FS_IRQHandler
*/
void OTG_FS_IRQHandler(void) {
  OS_EnterInterrupt(); // Inform embOS that interrupt code is running
  if (_pfUSBISRHandler) {
    (_pfUSBISRHandler)();
  }
  OS_LeaveInterrupt(); // Inform embOS that interrupt code is left
}

/*********************************************************************
*
*       OTG_HS_IRQHandler
*/
void OTG_HS_IRQHandler(void) {
  OS_EnterInterrupt(); // Inform embOS that interrupt code is running
  if (_pfUSBISRHandler) {
    (_pfUSBISRHandler)();
  }
  OS_LeaveInterrupt(); // Inform embOS that interrupt code is left
}

/*********************************************************************
*
*       BSP_USB_InstallISR_Ex()
*/
void BSP_USB_InstallISR_Ex(int ISRIndex, void (*pfISR)(void), int Prio){
  _pfUSBISRHandler = pfISR;

  NVIC_SetPriority((IRQn_Type)ISRIndex, (uint32_t)Prio);
  NVIC_EnableIRQ((IRQn_Type)ISRIndex);
}


/****** End Of File *************************************************/
